@@ -17,7 +17,7 @@ class TestTimestreamLoader_UnitTests:
     @pytest.mark.unit
     def test_load(self):
         mock_session = self.get_mock_session()
-        loader = TimestreamLoader('test.db', 'test.table', mock_session)
+        loader = TimestreamLoader('test', 'test', mock_session)
         mock_session.assert_expectations()
 
         result = loader.load(
@@ -37,8 +37,6 @@ class TestTimestreamLoader_UnitTests:
         assert type(result['rejected_records']) == list
         assert len(result['rejected_records']) == 0
         assert result['error'] == None
-        assert loader.database_name == 'test.db'
-        assert loader.table_name == 'test.table'
 
     @pytest.mark.unit
     def test_load_preview(self):
